Gammapy
=======

A Python Package for Gamma-ray Astronomy

* Webpage: https://gammapy.org
* Documentation: https://docs.gammapy.org/
* Code: https://github.com/gammapy/gammapy
* License: BSD-3

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org/

.. image:: http://mybinder.org/badge.svg
    :target: https://mybinder.org/v2/gh/gammapy/gammapy-webpage/master?urlpath=lab/tree/overview.ipynb

Status shields
++++++++++++++

(mostly useful for developers)

* .. image:: https://github.com/gammapy/gammapy/workflows/CI/badge.svg
    :target: https://github.com/gammapy/gammapy/actions
    :alt: GitHub actions CI

* .. image:: https://codecov.io/gh/gammapy/gammapy/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/gammapy/gammapy

* .. image:: https://img.shields.io/lgtm/grade/python/g/gammapy/gammapy.svg?logo=lgtm&logoWidth=18
    :target: https://lgtm.com/projects/g/gammapy/gammapy/context:python
    :alt: LGTM

* .. image:: https://app.codacy.com/project/badge/Grade/9c32a21a915d4a28823f3b44a99a2810
    :target: https://www.codacy.com/gh/gammapy/gammapy/dashboard?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=gammapy/gammapy&amp;utm_campaign=Badge_Grade
    :alt: Codacy

* .. image:: http://img.shields.io/pypi/v/gammapy.svg?text=version
    :target: https://pypi.org/project/gammapy/
    :alt: Latest release

* https://www.openhub.net/p/gammapy


Note if you cloned this repository before Oct 7th 2022
++++++++++++++++++++++++++++++++++++++++++++++++++++++

The  primary branch was renamed `main`. See the following instructions:
https://github.com/gammapy/gammapy/wiki/Changing-master-branch-to-main

